function pattern = dstat_pattern(tiwt,pindex,gamma,cflag,ncoeff);

% dstat_pattern -- return stationary wavelet pattern that corresponds
%                  to a given index into the tiwt table
% 
% Usage
%  pattern = dstat_pattern(tiwt,index,gamma,cflag,ncoeff);
%
% Inputs
%  tiwt		translation invariant wt data structure
%  pindex	index into the tiwt table (ranges from 1 to 2^M)
%  gamma	1/f^gamma parameter
%  cflag        1: use coarse approximation in detection statistic
%               0: only use detail approx in det. stat.
%               default = 0;
%  ncoeff       number of coefficients to return in the pattern
%               We return the top ncoeff coefficients 
%               (with respect to their contribution to the
%                2^(-gamma m) weighted detection statistic.
%
% Outputs
%  pattern	pattern matrix 
%                1st column: scale of the coefficient
%                2nd column: index of the coefficient within the scale
%                3rd column: value of the coefficient


	[n,M] = size(tiwt);
	M = M-1;

	totalshifts = 2^M;
	binary_index = mydec2bin(pindex-1,M);
	index = 1;

% Note: The TIWT indexing algorithm is from the Wavelab .700 function
% TI2Stat.m written by Shaobing Chen.

	pattern = [];
        energy = [];

	for m = 1:M
	   nb = 2^m;

	   index = [(index + nb/2);index];
	   index = index(:)';
           rindex = reverse(index);

           bin_index = binary_index((M-m+1):M);
           bin_index = mybin2dec(bin_index)+1;
           b = rindex(bin_index)-1;
   
	   this_pattern = tiwt(m*n + packet(m,b,n));       
           pattern = [pattern;
                      m*ones(length(this_pattern),1),...
		      (index(b+1):nb:n)',...
		      this_pattern(:)];
            energy = [energy;
                      (this_pattern(:).^2)*2^(-gamma*m)];

	end

        if cflag
	   this_pattern = tiwt(packet(m,b,n));       
           pattern = [pattern;
                      (m+1)*ones(length(this_pattern),1),...
		      (index(b+1):nb:n)',...
		      this_pattern(:)];
            energy = [energy;
                      (this_pattern(:).^2)*2^(-gamma*m)];
        end


        sum(energy)
        [energy,energy_ind] = sort(energy);
        energy_ind = reverse(energy_ind);
        use_ind = energy_ind(1:ncoeff);

%	sum(abs(energy) > eps)
%	sum(abs(pattern) > eps)

 
        pattern = pattern(use_ind,:);



% Copyright (c) 1998 Thomas T. Liu
%
% Note this function works in conjunction with
% routines and data structures from Wavelab version .700 which is copyrighted
% material from D.L. Donoho's group at Stanford University. 
